@@ -1,8 +1,8 @@
-from rest_framework.views import APIView
-from rest_framework.status import HTTP_200_OK, HTTP_400_BAD_REQUEST
 from rest_framework.response import Response
-
+from rest_framework.status import HTTP_200_OK, HTTP_400_BAD_REQUEST
+from rest_framework.views import APIView
 from sso_server.services.token_service import TokenService
+from sso_server.services.get_student_info import GetStudentInfo
 
 
 # Create your views here.
@@ -18,6 +18,18 @@ class UserDataView(APIView):
 		result = TokenService.get_user_info_by_token(request.META.get('HTTP_AUTHORIZATION'))
 		return Response(result, status=HTTP_200_OK)
 	
+	
+class GetStudentInfoView(APIView):
+	"""
+	получение данных студента
+	"""
+	
+	def post(self, request):
+		result = GetStudentInfo(request.POST.get('user_id'))
+		return Response(
+				result.get_student_info_by_param(request.POST.get('param')), status=HTTP_200_OK
+		)
+	
 
 class TokenView(APIView):
 	"""
